==> haskell-dlist-1.0-109-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dlist.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dlist
version:              1.0
visibility:           public
id:                   dlist-1.0-4uSjbl72fpn9e2vwvg1nn4
key:                  dlist-1.0-4uSjbl72fpn9e2vwvg1nn4
license:              BSD-3-Clause
copyright:
    2006-2009 Don Stewart, 2013-2020 Sean Leather, 2017-2020 Oleg Grenrus, contributors

maintainer:           Sean Leather <sean.leather@gmail.com>
author:               Don Stewart
homepage:             https://github.com/spl/dlist
synopsis:             Difference lists
description:          List-like types supporting O(1) append and snoc operations.
category:             Data
abi:                  2224f040d84363932f0c9f80d4547092
exposed:              True
exposed-modules:      Data.DList Data.DList.DNonEmpty Data.DList.Unsafe
hidden-modules:       Data.DList.Internal Data.DList.DNonEmpty.Internal
import-dirs:          /usr/lib/ghc-9.0.1/site-local/dlist-1.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/dlist-1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/dlist-1.0
hs-libraries:         HSdlist-1.0-4uSjbl72fpn9e2vwvg1nn4
depends:              base-4.15.0.0 deepseq-1.4.5.0
haddock-interfaces:   /usr/share/doc/haskell-dlist/html/dlist.haddock
haddock-html:         /usr/share/doc/haskell-dlist/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-dlist-1.0-110-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-dlist.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dlist
version:              1.0
visibility:           public
id:                   dlist-1.0-968votKXJv95y05SwCWWU0
key:                  dlist-1.0-968votKXJv95y05SwCWWU0
license:              BSD-3-Clause
copyright:
    2006-2009 Don Stewart, 2013-2020 Sean Leather, 2017-2020 Oleg Grenrus, contributors

maintainer:           Sean Leather <sean.leather@gmail.com>
author:               Don Stewart
homepage:             https://github.com/spl/dlist
synopsis:             Difference lists
description:          List-like types supporting O(1) append and snoc operations.
category:             Data
abi:                  f7a5428fe076dec48f81b682417557c9
exposed:              True
exposed-modules:      Data.DList Data.DList.DNonEmpty Data.DList.Unsafe
hidden-modules:       Data.DList.Internal Data.DList.DNonEmpty.Internal
import-dirs:          /usr/lib/ghc-9.0.1/site-local/dlist-1.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/dlist-1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/dlist-1.0
hs-libraries:         HSdlist-1.0-968votKXJv95y05SwCWWU0
depends:              base-4.15.0.0 deepseq-1.4.5.0
haddock-interfaces:   /usr/share/doc/haskell-dlist/html/dlist.haddock
haddock-html:         /usr/share/doc/haskell-dlist/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
